ImageServiceImpl class

Implemented types

Constructors

ImageServiceImpl()

Properties

hashCode → int
The hash code for this object.
no setterinherited
operations → Map<int, CommandHandler>
Map of command handlers. Upon reception of a WorkerRequest, the platform worker will dispatch the request to the CommandHandler mathing the value of WorkerRequest.command.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

crop(Uint8List imageData, int x, int y, int width, int height) → FutureOr<String?>
override
flip(Uint8List imageData, String axis) → FutureOr<String?>
override
gray(Uint8List imageData) → FutureOr<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resize(Uint8List imageData, int width, int height) → FutureOr<String?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited