ImageWorker class

Implemented types

Constructors

ImageWorker(dynamic entryPoint, {List args = const []})

Properties

args → List
The Worker's start arguments.
finalinherited
channel → Channel?
Channel to communicate with the worker.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
idleTime → Duration
Idle time.
no setterinherited
isStopped → bool
Indicates if the Worker has been stopped.
no setterinherited
maxWorkload → int
Maximum acceptable workload.
no setterinherited
operations → Map<int, CommandHandler>
Workers do not need an operations map.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stats → WorkerStat
Worker statistics.
no setterinherited
status → String
Worker status.
no setterinherited
totalErrors → int
Total errors.
no setterinherited
totalWorkload → int
Total processed workload.
no setterinherited
upTime → Duration
Up time.
no setterinherited
workerId → String
Worker ID
finalinherited
workload → int
Current workload.
no setterinherited

Methods

crop(Uint8List imageData, int x, int y, int width, int height) → Future<String?>
override
flip(Uint8List imageData, String axis) → Future<String?>
override
gray(Uint8List imageData) → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resize(Uint8List imageData, int width, int height) → Future<String?>
override
send<T>(int command, {List args = const [], CancellationToken? token, bool inspectRequest = false, bool inspectResponse = false}) → Future<T>
Sends a workload to the worker.
inherited
start() → Future<Channel>
Creates a Channel and starts the worker using the _entryPoint.
inherited
stop() → void
Stops this worker.
inherited
stream<T>(int command, {List args = const [], CancellationToken? token, bool inspectRequest = false, bool inspectResponse = false}) → Stream<T>
Sends a streaming workload to the worker.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited